@@ -71,7 +71,7 @@ class Matchers(object):
         :params expr: the statement to evaluate
         :params msg: (Optional) msg explaining the difference
         """
-        assert bool(expr) is True
+        assert bool(expr) is True, msg
 
     def verify_true(self, expr, msg=None):
         """
